The [Alexa Skills Kit Command Line Interface (ASK CLI)](https://developer.amazon.com/public/solutions/alexa/alexa-skills-kit/docs/ask-cli-command-reference) is a tool for you to manage your Alexa skills and related AWS Lambda functions. With the ASK CLI, you can now quickly and easily create new skills and update your existing skills from the command line and local development environment.

**The ASK CLI is currently in beta**. Until the end of the beta, we may introduce some changes in the functionality based on the customer feedback we receive.

## Step 1: Prerequisites for ASK CLI

- [Amazon developer account](http://developer.amazon.com) to manage your Alexa skills.
- [AWS account and credentials](https://developer.amazon.com/public/solutions/alexa/alexa-skills-kit/docs/set-up-credentials-for-an-amazon-web-services-account), if you plan to use AWS Lambda functions to host your skill's business logic.


## Step 2: Install ASK CLI

Use npm to install ASK CLI. Run the npm global install command into the ask-cli folder:

    $ npm install -g ask-cli

If you are using Linux, the installation may require `sudo`:

    $ sudo npm install -g ask-cli


## Step 3: Initialize ASK CLI

The first time you use ASK CLI, you must call the `init` command to initialize the tool with your Amazon developer account.

    $ ask init

You will be prompted to select your profile and to log in to your developer account. Once the initialization is complete, you can use ASK CLI to manage your skills.


## Step 4: Use ASK CLI Commands to Manage Your Skills

### Creating a new skill
The `ask new` command allows you to quickly create a new Alexa skill.

    $ ask new --skill-name 'my-skill'
    $ cd my-skill
    $ ask deploy

This will create a fully working "Hello World" skill that can be enabled and invoked immediately. If you make any subsequent changes, just use `ask deploy` again to deploy all of your changes.

### Working on an existing skill
The `ask clone` command allows you to set up a local project from your existing skill.

    $ ask clone --skill-id 'amzn1.ask.skill.UUID'
    $ cd my-existing-skill-name
    # make some changes here
    $ ask deploy

`ask deploy` will deploy all of your changes to skill manifest, interaction models, and AWS Lambda function(s).

To see all of the commands available in ASK CLI, refer to the [ASK CLI Reference](https://developer.amazon.com/public/solutions/alexa/alexa-skills-kit/docs/ask-cli-command-reference).


# Change Log #

## Janurary 31, 2018

v1.1.0 brings the ASK CLI out of beta, with a few notable changes.

- Added new API commands: delete-account-linking, enable-skill, disable-skill, get-skill-enablement.
- Added get-skill-status API and remove get-model-status API. Response for get-skill-status will include the status for manifest and all interaction models for the skill.
- Added optional "stage" parameter for the following API commands, allowing retrieval of live skill details: get-skill, get-model, head-model, get-account-linking.
- skill.json now has "manifest" instead of "skillManifest" as the top-level key. The merge field in /.ask/config will also be changed to "manifest".


## December 28, 2017

- Version: 1.0.0-beta.9
- Support the setting for default expiration time for create-account-linking API.


## December 7, 2017

- Version: 1.0.0-beta.8
- "ask new --template" message improvements.


## November 30, 2017

- Version: 1.0.0-beta.6
- Publish private skill management for ask-cli.


## November 22, 2017

- Version: 1.0.0-beta.5
- "ask new" supports option usage of "--template" now. User can select specific template as the start of skill development.


## October 27, 2017

- Version: 1.0.0-beta.4
- Support Lambda for India and FarEast region.


## October 13, 2017

- Version: 1.0.0-beta.3
- Add delete-skill command in "api" namespace.
- Check port usage for ask init to avoid port conflict.
- Forbid empty string for account linking creation.


## October 6, 2017

- Version: 1.0.0-beta.2
- Add constraints and filtering for skill names.


## September 12, 2017

- Version: 1.0.0-beta.1
- Error message improvement for Lambda operations.


## September 5, 2017

- Version: 1.0.0-beta.0
- Birthday for ask-cli.
